import React from 'react'
import {
  Avatar,
  lighten,
  makeStyles,
  Typography,
  Tooltip
} from '@material-ui/core'
import { FluentIcon } from '../../../utilities/FluentIcon'
import clsx from 'clsx'
import TimeAgo from 'timeago-react'
import { AvatarAlphabet } from '../../dataDisplay/AvatarAlphabet'

const useStyles = makeStyles((theme) => ({
  root: {
    marginBottom: theme.spacing(2)
  },
  topRow: {
    display: 'flex'
  },
  desc: {
    marginLeft: theme.spacing(0.5)
  },
  indent: {
    marginLeft: (props) =>
      props.avatarDisplay ? theme.spacing(6) : theme.spacing(4)
  },
  indentChildren: {
    marginLeft: (props) => (props.avatarDisplay ? theme.spacing(2) : 0),
    marginTop: (props) => (props.avatarDisplay ? theme.spacing(-1.5) : 0)
  },
  timestamp: {
    color: lighten(theme.palette.common.black, 0.5),
    marginTop: theme.spacing(-3)
  },
  actionUser: {
    marginRight: 10,
    marginLeft: 11
  },
  activityIcon: {
    marginTop: 2
  },
  action: {
    verticalAlign: 'text-bottom',
    lineHeight: 1.8
  },
  avatar: {
    width: 35,
    height: 35,
    textTransform: 'uppercase'
  }
}))

export const FluentActivity = (props) => {
  const classes = useStyles(props)
  const {
    activityIcon,
    avatar,
    avatarAlt,
    timeStamp,
    children,
    action,
    actionUser,
    avatarDisplay
  } = props

  const getUser = (userEmail) => {
    const regex = />(.*)</g
    const matches = regex.exec(userEmail)
    return matches[1].trim()?.charAt(0) || '?'
  }

  return (
    <div className={classes.root}>
      <div className={classes.topRow}>
        {activityIcon && (
          <div className={classes.activityIcon}>
            <FluentIcon component={activityIcon} />
          </div>
        )}
        {avatarDisplay && avatar && (
          <div className={classes.avatarContainer}>
            <Avatar alt={avatarAlt} className={classes.avatar} src={avatar} />
          </div>
        )}
        {avatarDisplay && !avatar && (
          <div className={classes.avatarContainer}>
            <AvatarAlphabet
              alt={avatarAlt}
              className={classes.avatar}
              avatarCharacter={getUser(
                actionUser.props.children[0].props.jsx
              ).toUpperCase()}
            >
              {getUser(actionUser.props.children[0].props.jsx)}
            </AvatarAlphabet>
          </div>
        )}

        <div className={classes.actionUser}>{actionUser}</div>

        <Typography variant='caption' className={classes.action}>
          {action}
        </Typography>
      </div>
      <div className={classes.indentChildren}>{children}</div>
      <div className={classes.time}>
        <Typography
          variant='caption'
          className={clsx(classes.indent, classes.timestamp)}
        >
          <Tooltip title={timeStamp}>
            <TimeAgo datetime={timeStamp} />
          </Tooltip>
        </Typography>
      </div>
    </div>
  )
}
