import React from 'react'
import { makeStyles, Paper, CardContent, Typography } from '@material-ui/core'
import { AvatarAlphabet, FluentIconButton } from 'unity-fluent-library-demo'
import { DeleteIcon } from '@fluentui/react-icons'
import { TrimForAvatar } from '../../../utilities/TrimForAvatar'
import TimeAgo from 'timeago-react'
import clsx from 'clsx'

const useStyles = makeStyles((theme) => ({
  root: {
    width: '100%',
    display: 'flex'
  },
  avatar: {
    marginRight: theme.spacing(2)
  },
  message: {
    width: '100%'
  },
  noteWrapper: {
    display: 'flex'
  },
  note: {
    flex: 1
  },
  date: {
    marginTop: theme.spacing(2)
  }
}))

export const Note = ({ children, author, date, className, onClick }) => {
  const classes = useStyles()

  return (
    <div className={clsx(classes.root, className)}>
      <div className={classes.avatar}>
        <AvatarAlphabet avatarCharacter={TrimForAvatar(author)} />
      </div>

      <Paper elevation={0} className={classes.message}>
        <CardContent>
          <div className={classes.noteWrapper}>
            <Typography variant='body2' className={classes.note}>
              {children}
            </Typography>
            <div>
              <FluentIconButton
                color='primary'
                icon={DeleteIcon}
                onClick={onClick}
              />
            </div>
          </div>
          <div className={classes.date}>
            <Typography variant='caption'>
              <TimeAgo datetime={date} />
            </Typography>
          </div>
        </CardContent>
      </Paper>
    </div>
  )
}
