import React from 'react'
import {
  Dialog,
  makeStyles,
  DialogActions,
  DialogContent,
  DialogContentText,
  DialogTitle
} from '@material-ui/core'
import { FluentButton } from 'unity-fluent-library-demo'

const useStyles = makeStyles((theme) => ({
  root: {},
  paper: {
    borderRadius: 2,
    borderTop: (props) =>
      props.header && `4px solid ${theme.palette.secondary.main}`
  },
  title: {
    color: (props) => props.header && theme.palette.secondary.main
  },
  actions: {
    marginBottom: 16,
    marginRight: 16
  }
}))

export const FluentDialog = (props) => {
  const classes = useStyles(props)
  const {
    title,
    message,
    actionOne,
    actionTwo,
    labelOne,
    labelTwo,
    open,
    handleClose,
    ariaLabelledby,
    ariaDescribedby,
    titleId,
    descriptionId,
    children,
    ...otherProps
  } = props

  return (
    <Dialog
      open={open}
      onClose={handleClose}
      aria-labelledby={ariaLabelledby}
      aria-describedby={ariaDescribedby}
      {...otherProps}
      classes={{
        paper: classes.paper
      }}
    >
      <DialogTitle className={classes.title} id={titleId}>
        {title}
      </DialogTitle>
      <DialogContent>
        <DialogContentText id={descriptionId}>{message}</DialogContentText>
        {children}
      </DialogContent>

      <DialogActions className={classes.actions}>
        <FluentButton onClick={actionOne} variant='contained' color='secondary'>
          {labelOne}
        </FluentButton>
        <FluentButton onClick={actionTwo} variant='outlined' color='primary'>
          {labelTwo}
        </FluentButton>
      </DialogActions>
    </Dialog>
  )
}
