import React from 'react'
import { Link } from 'react-router-dom'
import {
  Typography,
  Link as MuiLink,
  makeStyles,
  useTheme
} from '@material-ui/core'

const useStyles = makeStyles((theme) => ({
  root: {
    textDecoration: 'none',
    '& > * + *': {
      marginLeft: theme.spacing(2)
    }
  },
  link: {
    textDecoration: 'none',
    fontWeight: 700
  }
}))

export const FluentLink = (props) => {
  const {
    icon,
    alt,
    label,
    children,
    activeClassName,
    to,
    linkColor,
    ...otherProps
  } = props
  const theme = useTheme()
  const classes = useStyles()

  return to && to.substring(0, 4) !== 'http' ? (
    <Link
      to={to}
      activeClassName={activeClassName}
      className={classes.link}
      style={{
        color:
          linkColor === 'primary'
            ? theme.palette.primary.main
            : theme.palette.secondary.main
      }}
    >
      {children}
    </Link>
  ) : (
    <Typography component='div' className={classes.root}>
      <MuiLink
        {...otherProps}
        href={to}
        color={linkColor}
        variant='body1'
        style={{ textDecoration: 'none' }}
      >
        {children}
      </MuiLink>
    </Typography>
  )
}
