/* eslint-disable no-use-before-define */
import React from 'react'

import Autocomplete from '@material-ui/lab/Autocomplete'
import { makeStyles, TextField } from '@material-ui/core'

const useStyles = makeStyles((theme) => ({
  textField: {
    marginLeft: theme.spacing(1),
    marginRight: theme.spacing(1)
  },
  dense: {
    marginTop: theme.spacing(1)
  },
  input: {
    borderRadius: 2,
    height: 32,
    padding: 0,
    marginTop: 3
  },
  formTextInput: {
    fontSize: 14
  },
  labelRoot: {
    fontSize: 14
  }
}))

export const FluentSelectGroupMenu = ({
  data,
  placeholder,
  id,
  handleChange
}) => {
  const classes = useStyles()
  const options =
    data &&
    data.map((option) => {
      const firstLetter = option.label[0].toUpperCase()
      return {
        firstLetter: /[0-9]/.test(firstLetter) ? '0-9' : firstLetter,
        ...option
      }
    })

  return (
    <Autocomplete
      id={id}
      onChange={(event, value) => handleChange(value)}
      options={options.sort(
        (a, b) => -b.firstLetter.localeCompare(a.firstLetter)
      )}
      groupBy={(option) => option.firstLetter}
      getOptionLabel={(option) => option.label}
      style={{ width: 300 }}
      renderInput={(params) => (
        <TextField
          {...params}
          label={!params.inputProps.value && placeholder}
          variant='outlined'
          size='small'
          InputLabelProps={{
            shrink: false,
            classes: {
              root: classes.labelRoot,
              focused: classes.labelFocused
            }
          }}
          SelectProps={{
            MenuProps: {
              className: classes.menu
            }
          }}
        />
      )}
    />
  )
}
