import React, { useState } from 'react'
import { withStyles, lighten } from '@material-ui/core'
import MuiExpansionPanel from '@material-ui/core/ExpansionPanel'
import MuiExpansionPanelSummary from '@material-ui/core/ExpansionPanelSummary'
import MuiExpansionPanelDetails from '@material-ui/core/ExpansionPanelDetails'
import Typography from '@material-ui/core/Typography'

export const ExpansionPanel = withStyles((theme) => ({
  root: {
    boxShadow: 'none',
    minWidth: 300,
    '&:not(:last-child)': {
      borderBottom: 0
    },
    '&$expanded': {
      margin: 'auto',
      backgroundColor: lighten(theme.palette.primary.light, 0.3)
    }
  },
  expanded: {}
}))(MuiExpansionPanel)

export const ExpansionPanelSummary = withStyles((theme) => ({
  root: {
    backgroundColor: lighten(theme.palette.primary.light, 0.9),
    marginBottom: -1,
    minHeight: 40,
    '&$expanded': {
      minHeight: 40,
      backgroundColor: lighten(theme.palette.primary.light, 0.7)
    }
  },
  content: {
    '&$expanded': {
      margin: '12px 0'
    }
  },
  expanded: {}
}))(MuiExpansionPanelSummary)

export const ExpansionPanelDetails = withStyles((theme) => ({
  root: {
    padding: theme.spacing(2)
  }
}))(MuiExpansionPanelDetails)

export const Block = ({ label, children, number, id }) => {
  const [expanded, setExpanded] = useState('panel1')

  const handleChange = (panel) => (event, newExpanded) => {
    setExpanded(newExpanded ? panel : false)
  }
  return (
    <ExpansionPanel
      square
      expanded={expanded === `panel${number}`}
      onChange={handleChange(`panel${number}`)}
      id={id}
    >
      <ExpansionPanelSummary aria-controls='panel3d-content'>
        <Typography variant='subtitle2'>{label}</Typography>
      </ExpansionPanelSummary>
      <ExpansionPanelDetails>{children}</ExpansionPanelDetails>
    </ExpansionPanel>
  )
}
