import React, { useState } from 'react'
import { makeStyles } from '@material-ui/core'
import { FluentSimpleTabs } from '../defaultTabs/FluentSimpleTabs'
import { FluentSimpleTab } from '../defaultTabs/FluentSimpleTab'
import { FluentTabPanel } from '../defaultTabs/FluentTabPanel'
import clsx from 'clsx'

function a11yProps(index) {
  return {
    id: `simple-tab-${index}`,
    'aria-controls': `simple-tabpanel-${index}`
  }
}

const useStyles = makeStyles((theme) => ({
  root: {
    flexGrow: 1,
    backgroundColor: theme.palette.background.paper
  }
}))

export const FluentTabUtility = (props) => {
  const classes = useStyles()
  const { TabList, block, className } = props

  const [value, setValue] = useState(0)

  const handleChange = (event, newValue) => {
    setValue(newValue)
  }

  return (
    <div className={clsx(classes.root, className)}>
      <FluentSimpleTabs value={value} block={block} onChange={handleChange}>
        {TabList.map((item, index) => {
          return (
            <FluentSimpleTab
              key={index}
              label={item.label}
              {...a11yProps(index)}
              icon={item.icon}
              block={block}
            />
          )
        })}
      </FluentSimpleTabs>

      {TabList.map((item, index) => {
        return (
          <FluentTabPanel block={block} value={value} index={index} key={index}>
            {item.child}
          </FluentTabPanel>
        )
      })}
    </div>
  )
}
