import React from 'react'
import { makeStyles, Drawer, CardContent } from '@material-ui/core'
import { SideSheetHeader } from '../dataDisplay/typography/SideSheetHeader'

const useStyles = makeStyles((theme) => ({
  paper: {
    width: (props) => props.width || 320
  }
}))

/**
 * Base right hand side sheet with no contents
 */
export const BaseSideSheet = (props) => {
  const classes = useStyles(props)
  const { width, children, onClose, noBackdrop, ...drawerProps } = props

  return (
    <Drawer
      classes={classes}
      variant='temporary'
      anchor='right'
      onClose={onClose}
      {...drawerProps}
      BackdropProps={{ invisible: noBackdrop }}
    >
      {children}
    </Drawer>
  )
}

/**
 * A right hand material side sheet
 */
export const SideSheet = (props) => {
  const { children, title, ...otherProps } = props
  const { onClose } = props

  return (
    <BaseSideSheet {...otherProps}>
      <SideSheetHeader onClose={onClose} title={title} />
      <CardContent> {children}</CardContent>
    </BaseSideSheet>
  )
}
