import React, { useState, useEffect } from 'react'
import {
  makeStyles,
  CardContent,
  Typography,
  Avatar,
  Chip,
  Divider,
  lighten
} from '@material-ui/core'
import { FluentCard } from './FluentCard'
import { CopyToClipboard } from 'react-copy-to-clipboard'
import { CopyIcon, CheckMarkIcon } from '@fluentui/react-icons'
import { FluentIconButton } from 'unity-fluent-library-demo'
import clsx from 'clsx'

const useStyles = makeStyles((theme) => ({
  root: {
    width: '100%',
    height: '100%'
  },
  large: {
    width: theme.spacing(12),
    height: theme.spacing(12),
    border: `3px solid ${theme.palette.primary.main}`
  },
  info: {
    display: 'flex',
    marginTop: theme.spacing(3)
  },
  header: {
    display: 'flex'
  },
  addressContainer: {
    maxWidth: theme.spacing(16),
    alignContent: 'center',
    marginLeft: theme.spacing(3),
    marginBottom: theme.spacing(3)
  },
  lastName: {
    marginTop: theme.spacing(-1)
  },
  name: {
    flex: 1
  },
  chip: {
    background: lighten(theme.palette.success.light, 0.7)
  }
}))

export const BioCard = ({
  children,
  avatar,
  alt,
  firstName,
  lastName,
  address,
  copy,
  className
}) => {
  const classes = useStyles()

  const [state, setState] = useState({
    value: '',
    copied: false
  })

  useEffect(() => {
    setState({ value: copy })
  }, [copy])

  return (
    <FluentCard className={clsx(classes.root, className)}>
      <CardContent>
        <div className={classes.header}>
          <div className={classes.name}>
            <Typography variant='h4'>{firstName} </Typography>
            <div className={classes.lastName}>
              <Typography className={classes.overline} variant='overline'>
                {lastName}
              </Typography>
            </div>
          </div>
          {copy && !state.copied && (
            <div>
              <CopyToClipboard
                text={state.value}
                onCopy={() => setState({ ...state, copied: true })}
              >
                <FluentIconButton color='primary' icon={CopyIcon} />
              </CopyToClipboard>
            </div>
          )}
          {state.copied && (
            <div>
              <Chip
                label='Copied'
                avatar={<CheckMarkIcon />}
                variant='outlined'
                className={classes.chip}
                size='small'
              />
            </div>
          )}
        </div>

        <div className={classes.info}>
          <div className={classes.avatarWrapper}>
            <Avatar className={classes.large} alt={alt} src={avatar} />
          </div>
          <div className={classes.addressContainer}>{address}</div>
        </div>
      </CardContent>
      {children && <Divider />}
      <CardContent>{children}</CardContent>
    </FluentCard>
  )
}
