import { MoreIcon } from '@fluentui/react-icons'
import { Button, makeStyles, Menu } from '@material-ui/core'
import clsx from 'clsx'
import React, { forwardRef } from 'react'
import { FluentIcon } from '../../../utilities/FluentIcon'
import FUICardHeader from './FUICardHeader'
import FUISquareIconButton from '../../inputs/buttons/FUISquareIconButton'
import { FluentCard } from './FluentCard'
import { FluentCardContent } from './FluentCardContent'
import { FluentCardActions } from './FluentCardActions'
import useId from '../../widgets/utils/useId'

const useStyles = makeStyles(
  (theme) => ({
    root: {
      display: 'flex',
      flexDirection: 'column'
    },
    raised: {
      zIndex: 1
    },
    contentArea: {
      flex: '1 1 auto',
      minHeight: 0,
      display: 'flex',
      flexDirection: 'column'
    },
    cardActions: {
      display: 'flex',
      flexDirection: 'row',
      justifyContent: 'flex-start',
      paddingTop: theme.spacing(1),
      padding: theme.spacing(2)
    }
  }),
  { name: 'FUICard' }
)

export let FUICardAction = (props, ref) => {
  const { children, ...other } = props

  return (
    <Button
      ref={ref}
      size='small'
      variant='contained'
      disableElevation
      {...other}
    >
      {children}
    </Button>
  )
}
FUICardAction = forwardRef(FUICardAction)

export let FUICardHeaderMenu = (props, ref) => {
  const { children } = props

  return (
    <div
      button={
        <FUISquareIconButton>
          <FluentIcon component={MoreIcon} size='small' />
        </FUISquareIconButton>
      }
      menu={<Menu>{children}</Menu>}
    />
  )
}
FUICardHeaderMenu = forwardRef(FUICardHeaderMenu)

const FUICard = (props, ref) => {
  const classes = useStyles()
  const {
    className,
    children,
    actions,
    title,
    headerActions,
    CardHeaderProps,
    CardProps,
    raised,
    name,
    ...cardProps
  } = props
  const id = useId(name, cardProps.id)
  const titleId = `${id}-title`

  return (
    <FluentCard
      ref={ref}
      component='section'
      aria-labelledby={titleId}
      {...cardProps}
      raised={raised}
      className={clsx(className, raised && classes.raised)}
      {...CardProps}
      classes={{ root: classes.root }}
    >
      <FUICardHeader
        titleId={titleId}
        headerActions={headerActions}
        {...CardHeaderProps}
      >
        {title}
      </FUICardHeader>
      <FluentCardContent className={classes.contentArea}>
        {children}
      </FluentCardContent>
      {actions && (
        <FluentCardActions className={classes.cardActions}>
          {actions}
        </FluentCardActions>
      )}
    </FluentCard>
  )
}

export default forwardRef(FUICard)
