import React, { Fragment } from 'react'
import {
  makeStyles,
  CardContent,
  Divider,
  lighten,
  Typography
} from '@material-ui/core'
import { LayoutUnit, FluentCard } from 'unity-fluent-library-demo'
import PropTypes from 'prop-types'

const useStyles = makeStyles((theme) => ({
  root: {},
  paper: {
    background: lighten(theme.palette.info.light, 0.8),
    borderTop: `5px solid ${theme.palette.info.main} `
  },
  title: {
    color: theme.palette.info.dark,
    highlightfontWeight: 400,
    lineHeight: 1.6
  },
  subHeader: {
    lineHeight: 1.6,
    fontWeight: 600
  }
}))

export const InfoCard = ({
  children,
  title,
  subTitle,
  relatedTopics,
  label,
  headerComponent = 'h2',
  subHeaderComponent = 'h3',
  size = 'standard'
}) => {
  const classes = useStyles()

  return (
    <div className={classes.root}>
      <FluentCard elevation={0} classes={{ root: classes.paper }}>
        <CardContent>
          <Typography
            variant='h6'
            component={headerComponent}
            className={classes.title}
          >
            {title}
          </Typography>
          {size === 'standard' && <LayoutUnit unit='xxs' />}
          <Typography
            variant='subtitle1'
            component={subHeaderComponent}
            className={classes.subHeader}
          >
            {subTitle}
          </Typography>
          {children}
          {size === 'standard' && <LayoutUnit unit='xxs' />}

          {relatedTopics && (
            <Fragment>
              <Divider />
              <LayoutUnit unit='xxs' />
              <Typography variant='caption'>
                {label || 'Related Topics'}
              </Typography>
              <LayoutUnit unit='xxs' />
              {relatedTopics}
            </Fragment>
          )}
        </CardContent>
      </FluentCard>
    </div>
  )
}

InfoCard.propTypes = {
  /**
   * Main content for the card
   */
  children: PropTypes.oneOfType([
    PropTypes.arrayOf(PropTypes.node),
    PropTypes.node
  ]),
  /**
   * Card title
   */
  title: PropTypes.string.isRequired,
  /**
   * Optional card subtitle
   */
  subTitle: PropTypes.string,
  /**
   * Option list of related topics
   */
  relatedTopics: PropTypes.oneOfType([
    PropTypes.arrayOf(PropTypes.node),
    PropTypes.node
  ]),
  /**
   * Title for related topics or alt title
   */
  label: PropTypes.string,
  /**
   * Change semantic header of card title
   */
  headerComponent: PropTypes.string,
  /**
   * Change semantic header of card subtitle
   */
  subHeaderComponent: PropTypes.string,
  /**
   * Card size override for dense card
   */
  size: PropTypes.oneOf(['standard'])
}

InfoCard.defaultProps = {
  headerComponent: 'h2',
  subHeaderComponent: 'h3',
  size: 'standard'
}
