import React, { useState } from 'react'
import { makeStyles } from '@material-ui/core'
import { FluentIconButton } from 'unity-fluent-library-demo'
import { ChevronRightIcon, ChevronLeftIcon } from '@fluentui/react-icons'

export const SapFlexibleTemplate = ({ left, center, right }) => {
  const [columns, setColumns] = useState({
    columnLeft: true,
    columnCenter: true,
    columnRight: true
  })

  const [columnPercent, setColumnPercent] = useState({
    columnLeft: '25%',
    columnCenter: '50%',
    columnRight: '25%'
  })

  const useStyles = makeStyles((theme) => ({
    root: {
      display: 'flex',
      flexDirection: 'row'
    },
    columnLeft: {
      display: 'flex',
      flex: columnPercent.columnLeft,
      height: '100vh'
    },
    columnCenter: {
      flex: columnPercent.columnCenter,
      height: '100vh'
    },
    columnRight: {
      display: 'flex',
      flex: columnPercent.columnRight,
      height: '100vh'
    },
    fillContent: {
      flex: 1
    }
  }))

  const classes = useStyles()

  const handleToggleColumn = (columnType) => {
    setColumns({ ...columns, columnCenter: !columns.columnCenter })

    if (columnType === 'columnLeft') {
      setColumnPercent({ ...columnPercent, columnLeft: '75%' })

      if (columnPercent.columnLeft === '75%') {
        setColumnPercent({ ...columnPercent, columnLeft: '25%' })
      }
    } else {
      setColumnPercent({ ...columnPercent, columnRight: '75%' })

      if (columnPercent.columnRight === '75%') {
        setColumnPercent({ ...columnPercent, columnRight: '25%' })
      }
    }
  }

  return (
    <div className={classes.root}>
      {columns.columnLeft && (
        <div className={classes.columnLeft}>
          <div className={classes.fillContent}>{left} </div>
          <div className={classes.toggle}>
            <FluentIconButton
              aria-label={
                columnPercent.columnLeft === '25%'
                  ? 'Expand column'
                  : 'Collapse column'
              }
              color='primary'
              icon={
                columnPercent.columnLeft === '25%'
                  ? ChevronRightIcon
                  : ChevronLeftIcon
              }
              onClick={() => handleToggleColumn('columnLeft')}
            />
          </div>
        </div>
      )}

      {columns.columnCenter && (
        <div className={classes.columnCenter}>
          <div> {center} </div>
        </div>
      )}

      {columns.columnRight && (
        <div className={classes.columnRight}>
          <div className={classes.toggle}>
            <FluentIconButton
              aria-label={
                columnPercent.columnRight === '25%'
                  ? 'Expand column'
                  : 'Collapse column'
              }
              color='primary'
              icon={
                columnPercent.columnRight === '25%'
                  ? ChevronLeftIcon
                  : ChevronRightIcon
              }
              onClick={() => handleToggleColumn('columnRight')}
            />
          </div>
          <div className={classes.fillContent}> {right} </div>
        </div>
      )}
    </div>
  )
}
