import React, { Fragment } from 'react'
import { Card, makeStyles, IconButton } from '@material-ui/core'
import clsx from 'clsx'
import { FluentIcon } from '../../utilities/FluentIcon'
import { ChromeCloseIcon, ChevronDownMedIcon } from '@fluentui/react-icons'
import { SubHeaderActionsTarget } from '../../utilities/utilityBar/SubHeaderAction'

const useStyles = makeStyles(
  (theme) => ({
    root: {
      background: theme.palette.primary.light,
      minHeight: theme.spacing(12)
    },
    bar: {
      display: 'flex',
      flexDirection: 'row'
    },
    gutters: {
      paddingLeft: theme.spacing(2)
    },
    content: {
      flex: 1
    },
    collapsed: {
      height: 0,
      transition: theme.transitions.create('height', {
        easing: theme.transitions.easing.easeOut,
        duration: theme.transitions.duration.leavingScreen
      })
    },
    expanded: {
      transition: theme.transitions.create('height', {
        easing: theme.transitions.easing.easeIn,
        duration: theme.transitions.duration.enteringScreen
      })
    },
    open: {
      display: 'flex',
      justifyContent: 'flex-end'
    },
    toggleButton: {
      padding: theme.spacing(1)
    }
  }),
  { name: 'UtilityBar' }
)

export const UtilityBar = (props) => {
  const classes = useStyles()
  const { expanded = true, toggle, gutters = true, className } = props

  return (
    <Fragment>
      {expanded && (
        <Card
          className={clsx(
            classes.root,
            className,
            expanded ? classes.expanded : classes.collapsed
          )}
          variant='outlined'
          square
        >
          <div>
            <div className={clsx(classes.bar, gutters && classes.gutters)}>
              <div className={classes.content}>
                <SubHeaderActionsTarget className={classes.actions} />
              </div>
              <div className={classes.toggleButton}>
                <IconButton onClick={toggle} aria-label='Toggle Utility Bar'>
                  <FluentIcon size='small' component={ChromeCloseIcon} />
                </IconButton>
              </div>
            </div>
          </div>
        </Card>
      )}

      {!expanded && (
        <div className={classes.open}>
          <div className={classes.bar}>
            <div className={classes.toggleButton}>
              <IconButton onClick={toggle}>
                <FluentIcon size='small' component={ChevronDownMedIcon} />
              </IconButton>
            </div>
          </div>
        </div>
      )}
    </Fragment>
  )
}
