import React from 'react';
import { Typography, makeStyles } from '@material-ui/core';
import round from '@extra-number/round';
import FluentTrendArrow from './FluentTrendArrow';

const useStyles = makeStyles(theme => ({
  root: {},
  percent: {
    display: 'flex',
    flexDirection: 'row',
    marginTop: theme.spacing(-0.5),
  },
  arrow: {
    display: 'flex',
    flexDirection: 'column',
    justifyContent: 'center',
  },
  percentAmount: {},
}));

const FluentStatsSnippet = props => {
  const classes = useStyles(props);
  const {
    label,
    amount: rawAmount,
    prevAmount,
    percent: percentProp,
    trend: trendProp,
  } = props;

  // @todo Use an Intl formatter
  let amount = rawAmount;
  // TODO: Revisit below after Tampa Demo
  if (Math.abs(rawAmount) > 1_000_000) {
    //amount = Math.floor(rawAmount / 1_000_000) + 'M';
    let newNumber = rawAmount / 1_000_000;
    amount = [Math.round(newNumber * 10) / 10, 'M'];
  } else if (Math.abs(rawAmount) > 1_000) {
    //amount = Math.floor(rawAmount / 1_000) + 'K';
    let newNumber = rawAmount / 1_000;
    amount = [Math.round(newNumber * 10) / 10, 'K'];
  }

  let percent = percentProp;
  let trend = trendProp;
  if (typeof prevAmount === 'number') {
    const ratio = (rawAmount - prevAmount) / prevAmount;

    percent =
      Math.abs(round(ratio * 100, Math.abs(ratio) < 0.01 ? 0.01 : 1)) + '%';
    trend = ratio < 0 ? 'down' : 'up';
  }

  return (
    <div className={classes.root}>
      <Typography variant="overline" component="div">
        {label}
      </Typography>
      <Typography className={classes.stat} variant="h5" component="div">
        {amount}
      </Typography>
      <div className={classes.percent}>
        <div className={classes.arrow}>
          <FluentTrendArrow type={trend} />
        </div>
        <div className={classes.percentAmount}>
          <Typography variant="caption">{percent}</Typography>
        </div>
      </div>
    </div>
  );
};
export default FluentStatsSnippet;
