import React from 'react'
import { Avatar, makeStyles, Typography } from '@material-ui/core'
import FluentDisplayNumber from '../atoms/FluentDisplayNumbers'
import { MarketIcon, MarketDownIcon } from '@fluentui/react-icons'
import { FluentIcon } from '../../../../utilities/FluentIcon'

const useStyles = makeStyles(
  (theme) => ({
    root: {
      display: 'flex',
      flexDirection: 'row'
    },
    caption: {
      marginTop: -28,
      textAlign: 'left'
    },
    captionSmall: {
      marginTop: -16,
      textAlign: 'center'
    },
    trend: {
      marginTop: theme.spacing(2),
      marginLeft: theme.spacing(1)
    },
    upIcon: {
      color: 'green'
    },
    downIcon: {
      color: '#D50000'
    },
    avatar: {
      backgroundColor: 'white'
    }
  }),
  { next: 'FluentStatNumber' }
)

const FluentStatNumber = (props) => {
  const classes = useStyles()
  const { small, trend, label, number } = props
  return (
    <div className={classes.root}>
      <div>
        <div>
          <FluentDisplayNumber small={small} number={Math.abs(number)} />
        </div>
        <div className={!small ? classes.caption : classes.captionSmall}>
          <Typography variant='overline'>{label}</Typography>
        </div>
      </div>

      <div className={classes.trend}>
        {small && (
          <Avatar className={classes.avatar}>
            {trend === 'down' ? (
              <FluentIcon
                component={MarketDownIcon}
                className={classes.downIcon}
              />
            ) : (
              <FluentIcon component={MarketIcon} className={classes.upIcon} />
            )}
          </Avatar>
        )}
      </div>
    </div>
  )
}
export default FluentStatNumber
