import React from 'react'
import { makeStyles, Typography } from '@material-ui/core'
import NumberVisualization from '../../utils/NumberVisualization'

const useStyles = makeStyles((theme) => ({
  root: {
    display: 'flex',
    flexDirection: 'row',
    marginTop: theme.spacing(3),
    marginLeft: theme.spacing(2),
    overflow: 'auto'
  },
  dot: {
    width: 10,
    height: 10,
    backgroundColor: 'white',
    borderRadius: theme.shape.borderRadius + 25,
    marginTop: theme.spacing(1)
  },
  timeLabels: {
    color: 'white'
  },
  indicator: {
    display: 'flex',
    flexDirection: 'column',
    justifyContent: 'flex-end',
    marginRight: theme.spacing(2),
    textAlign: 'center',
    alignItems: 'center'
  }
}))

const TimeDot = (props) => {
  const classes = useStyles()
  const { dot } = props
  return (
    <div className={classes.indicator}>
      <div className={classes.dot} />
      <div className={classes.timeLabels}>
        <Typography variant='overline'>{dot}</Typography>
      </div>
    </div>
  )
}

const Visualization = (props) => {
  const classes = useStyles()
  const { value, label } = props
  return (
    <div className={classes.indicator}>
      <div>
        <NumberVisualization number={value} />
      </div>
      <div>
        <TimeDot dot={label} />
      </div>
    </div>
  )
}

const categoriesToDisplay = (categories) =>
  categories.map((item) => {
    return (
      <Visualization key={item.label} value={item.value} label={item.label} />
    )
  })

const FluentTimeline = (props) => {
  const classes = useStyles()
  const { categories } = props

  return <div className={classes.root}>{categoriesToDisplay(categories)}</div>
}
export default FluentTimeline
