import React, { Fragment } from 'react'
import { DeleteIcon } from '@fluentui/react-icons'
import { makeStyles, CircularProgress } from '@material-ui/core'
import clsx from 'clsx'
import FUICard, { FUICardHeaderMenu } from '../surfaces/cards/FUICard'
import FUIMenuItem from './FluentComponents/FUIMenuItem'

/**
 * Core component for dashboard widget cards
 */
const WidgetCard = (props) => {
  const {
    children,
    headerActions,
    className,
    widgetType,
    id,
    layout,
    params,
    setParam,
    onDelete,
    loading,
    errors,
    theme,
    ...other
  } = props

  const useStyles = makeStyles((theme) => ({
    root: {
      '&.react-resizable-hide .react-resizable-handle': {
        display: 'none'
      }
    },
    darkRoot: {
      '&.react-resizable-hide .react-resizable-handle': {
        display: 'none'
      },
      background: '#424242',
      color: 'white'
    },
    anyRoot: {
      '& .MuiCardContent-root': {
        justifyContent: 'space-between',
        overflow: 'auto',
        padding: 0
      }
    },
    handle: {
      cursor: 'move',
      '&:hover': {
        backgroundColor: theme.palette.action.hover
      }
    },
    loadingContent: {
      flex: 1,
      display: 'flex',
      flexDirection: 'column',
      alignItems: 'center',
      justifyContent: 'center'
    },
    innerWidgetContentContainer: {
      height: '100%',
      minWidth: widgetType === 'ProgressBarWidget' ? 0 : 270,
      display: 'flex',
      flexDirection: 'column',
      justifyContent: 'space-between',
      padding: theme.spacing(2)
    }
  }))
  const classes = useStyles()

  const raised = /(^|\s)react-draggable-dragging(\s|$)/.test(className ? className: '')
  let body = children
  if (loading) {
    body = (
      <div className={classes.loadingContent}>
        <CircularProgress color='secondary' size={64} />
      </div>
    )
  }
  if (errors && !body) {
    body = <div>Unexpected error</div>
  }
  return (
    <FUICard
      {...other}
      className={clsx(
        className,
        theme === 'dark' ? classes.darkRoot : classes.root,
        classes.anyRoot
      )}
      raised={raised}
      CardHeaderProps={{
        className: classes.handle,
        'data-handle': true
      }}
      headerActions={
        <Fragment>
          {headerActions}
          <FUICardHeaderMenu>
            <FUIMenuItem
              onClick={onDelete}
              fluentIcon={DeleteIcon}
              primary='Delete'
            />
          </FUICardHeaderMenu>
        </Fragment>
      }
    >
      <div className={classes.innerWidgetContentContainer}>{body}</div>
    </FUICard>
  )
}

export default WidgetCard
