import React, { forwardRef, Fragment } from 'react'
import { Grid, Box, Typography } from '@material-ui/core'
import { MuiVegaLite } from '@material-vega/material-ui'
import WidgetCard from '../WidgetCard'
import FluentStatsSnippet from '../FluentComponents/atoms/FluentStatsSnippet'
import { convertISODate } from '../utils/ConvertISODate'

export const layout = {
  w: { default: 2, min: 0, max: 4 },
  h: { default: 2, min: 0, max: 4 }
}

export const params = {
  mode: {
    defaultValue: 'chart'
  }
}

const BarChartWidget = (props, ref) => {
  const { children, params, setParam, ...other } = props
  const { mockData, apiUrl, theme, dateRange } = params

  return (
    <WidgetCard
      ref={ref}
      {...other}
      title={mockData?.title}
      theme={theme && theme}
    >
      {mockData ? (
        <Fragment>
          {dateRange && (
            <Typography gutterBottom variant='caption' component='h3'>
              From: {convertISODate(dateRange.from)} to:{' '}
              {convertISODate(dateRange.to)}
            </Typography>
          )}
          {mockData?.stats && (
            <Grid container>
              {mockData?.stats.map((stat) => (
                <Grid item xs={3} key={stat.label}>
                  <FluentStatsSnippet
                    label={stat.label}
                    amount={stat.currentValue}
                    prevAmount={stat.previousValue}
                  />
                </Grid>
              ))}
            </Grid>
          )}
          <Box clone flex={1} mt={1} overflow='hidden'>
            <MuiVegaLite
              width='container'
              height='container'
              autoResize='true'
              variant='verticalBarChart'
              spec={{
                $schema: 'https://vega.github.io/schema/vega-lite/v4.json',
                data: {
                  values: mockData?.data
                },
                mark: 'bar',
                encoding: {
                  x: {
                    field: 'xAxis',
                    type: mockData?.xAxisType,
                    axis: {
                      ticks: false
                    },
                    band: 0.5
                  },
                  y: {
                    field: 'yAxis',
                    type: mockData?.yAxisType,
                    axis: {
                      format: mockData?.yAxisFormat
                    }
                  }
                }
              }}
            />
          </Box>
          {children}
        </Fragment>
      ) : (
        <Typography variant='subtitle2'>
          Could not retrieve widget data. Please contact support.
        </Typography>
      )}
    </WidgetCard>
  )
}

export default forwardRef(BarChartWidget)
