import React, { forwardRef } from 'react'
import { Grid, Box } from '@material-ui/core'
import WidgetCard from '../WidgetCard'
import FluentStatsSnippet from '../FluentComponents/atoms/FluentStatsSnippet'
import FluentTimeLine from '../FluentComponents/molecules/FluentTimeline'

export const layout = {
  w: { default: 2, min: 0, max: 4 },
  h: { default: 2, min: 0, max: 4 }
}

export const params = {
  mode: {
    defaultValue: 'chart'
  }
}

const BubbleWidget = (props, ref) => {
  const { children, params, setParam, ...other } = props
  const { mockData, apiUrl, theme } = params

  return (
    <WidgetCard ref={ref} {...other} title={mockData?.title} theme={theme}>
      <Grid container>
        {mockData?.stats?.map((stat) => (
          <Grid item xs={3} key={stat.label}>
            <FluentStatsSnippet
              label={stat.label}
              amount={stat.currentValue}
              prevAmount={stat.previousValue}
            />
          </Grid>
        ))}
      </Grid>
      <Box clone flex={1} mt={1} overflow='hidden'>
        <FluentTimeLine categories={mockData?.data} />
      </Box>
      {children}
    </WidgetCard>
  )
}

export default forwardRef(BubbleWidget)
