import { Grid, makeStyles } from '@material-ui/core'
import React, { forwardRef } from 'react'
import FluentPrimaryStatNumber from '../FluentComponents/molecules/FluentPrimaryStatNumber'
import FluentSecondaryStatNumber from '../FluentComponents/molecules/FluentSecondaryStatNumber'
import WidgetCard from '../WidgetCard'

const useStyles = makeStyles((theme) => ({
  column: {
    width: 160
  }
}))

export const layout = {
  w: { default: 2, min: 0, max: 4 },
  h: { default: 2, min: 0, max: 4 }
}

const DateTrendWidget = (props, ref) => {
  const classes = useStyles()
  const { children, params, setParam, ...other } = props
  const { mockData, apiUrl, theme } = params

  return (
    <WidgetCard ref={ref} {...other} title={mockData?.title} theme={theme}>
      <Grid container direction='row' spacing={1}>
        <Grid item className={classes.column}>
          <FluentPrimaryStatNumber
            mainStat={mockData?.primary.value}
            mainLabel={mockData?.primary.label}
          />
        </Grid>
        <Grid item>
          {mockData?.secondary.map((secondary) => (
            <Grid item key={secondary.category}>
              <FluentSecondaryStatNumber
                secondaryStat={secondary.value}
                secondaryLabel={secondary.category}
                trend={secondary.value < 0 ? 'down' : 'up'}
              />
            </Grid>
          ))}
        </Grid>
      </Grid>
      {children}
    </WidgetCard>
  )
}

export default forwardRef(DateTrendWidget)
