import React, { forwardRef } from 'react'
import { Box } from '@material-ui/core'
import { MuiVegaLite } from '@material-vega/material-ui'
import WidgetCard from '../WidgetCard'

export const layout = {
  w: { default: 2, min: 0, max: 4 },
  h: { default: 2, min: 0, max: 4 }
}

export const params = {
  mode: {
    defaultValue: 'chart'
  }
}

const DensePlotWidget = (props, ref) => {
  const { children, params, setParam, ...other } = props
  const { mockData, apiUrl, theme } = params

  return (
    <WidgetCard ref={ref} {...other} title={mockData?.title} theme={theme}>
      <Box clone flex={1} mt={1} overflow='hidden'>
        <MuiVegaLite
          variant='scatterplotChart'
          spec={{
            $schema: 'https://vega.github.io/schema/vega-lite/v4.json',
            description: mockData?.description,
            data: {
              values: mockData?.data
            },
            mark: 'point',
            height: 180,
            encoding: {
              x: { field: 'xAxis', type: mockData?.xAxisType },
              y: { field: 'yAxis', type: mockData?.yAxisType }
            }
          }}
        />
      </Box>
      {children}
    </WidgetCard>
  )
}

export default forwardRef(DensePlotWidget)
