import React, { forwardRef } from 'react'
import {
  makeStyles,
  Typography,
  useTheme,
  Divider,
  Box
} from '@material-ui/core'
import { MuiVegaLite } from '@material-vega/material-ui'
import { Sparklines, SparklinesLine } from 'react-sparklines'
import WidgetCard from '../WidgetCard'
import FluentStatNumber from '../FluentComponents/molecules/FluentStatNumber'
import { convertISODate } from '../utils/ConvertISODate'

export const layout = {
  w: { default: 2, min: 0, max: 4 },
  h: { default: 2, min: 0, max: 4 }
}

// export const params = {
//   mode: {
//     defaultValue: 'chart',
//   },
// };

const useStyles = makeStyles((theme) => ({
  displayItems: {
    display: 'flex',
    flexDirection: 'row',
    width: '100%'
  },
  visualCaption: {
    marginTop: theme.spacing(-1)
  },
  lineGraph: {
    width: '100%',
    '& svg': { width: '100%' }
  }
}))

const LineAndSparklinesWidget = (props, ref) => {
  const { children, params, setParam, ...other } = props
  const { mockData, apiUrl, theme, dateRange } = params
  const classes = useStyles()
  const mainTheme = useTheme()

  return (
    <WidgetCard ref={ref} title={mockData?.title} theme={theme} {...other}>
      {mockData ? (
        <div>
          {dateRange && (
            <Typography gutterBottom variant='caption' component='h3'>
              From: {convertISODate(dateRange.from)} to:{' '}
              {convertISODate(dateRange.to)}
            </Typography>
          )}
          <div className={classes.displayItems}>
            <div>
              <FluentStatNumber number={mockData?.value} trend='up' />
            </div>
            <div style={{ width: '100%' }}>
              <Sparklines
                data={mockData?.sparklinesData}
                strokeWidth={1}
                style={{ width: '100%', height: 45, marginTop: 10 }}
              >
                <SparklinesLine color={mainTheme.palette.secondary.main} />
              </Sparklines>
              <div className={classes.visualCaption}>
                <div>
                  <Divider />
                </div>

                <Typography variant='caption'>{mockData?.label}</Typography>
              </div>
            </div>
          </div>

          <Box clone flex={1} mt={1} overflow='hidden'>
            <MuiVegaLite
              variant='areaLineChart'
              style={{
                width: '100%'
              }}
              spec={{
                $schema: 'https://vega.github.io/schema/vega-lite/v4.json',
                height: 150,
                data: { values: mockData?.data },
                mark: 'area',
                encoding: {
                  x: {
                    field: 'xAxis',
                    type: mockData?.xAxisType
                  },
                  y: {
                    aggregate: 'sum',
                    field: 'yAxis',
                    type: mockData?.yAxisType,
                    scale: { domain: mockData?.domain || '' }
                  }
                }
              }}
              autoResize='true'
              width='container'
            />
          </Box>
          {children}
        </div>
      ) : (
        <Typography variant='subtitle2'>
          Could not retrieve widget data. Please contact support.
        </Typography>
      )}
    </WidgetCard>
  )
}

export default forwardRef(LineAndSparklinesWidget)
