import React, { forwardRef, Fragment } from 'react'
import FluentPrimaryStatNumber from '../FluentComponents/molecules/FluentPrimaryStatNumber'
import WidgetCard from '../WidgetCard'
import {
  LinearProgress,
  Typography,
  Divider,
  makeStyles
} from '@material-ui/core'
import FluentSecondaryStatNumber from '../FluentComponents/molecules/FluentSecondaryStatNumber'
import { convertISODate } from '../utils/ConvertISODate'

export const layout = {
  w: { default: 2, min: 0, max: 4 },
  h: { default: 2, min: 0, max: 4 }
}

const useStyles = makeStyles((theme) => ({
  root: {},
  displayItems: {
    display: 'flex',
    flexDirection: 'row',
    justifyContent: 'space-around',
    color: 'white'
  },
  divider: {
    marginTop: theme.spacing(4),
    marginBottom: theme.spacing(2)
  }
}))

const ProgressBarWidget = (props, ref) => {
  const { children, params, setParam, ...other } = props
  const { mockData, apiUrl, theme, dateRange } = params
  const classes = useStyles()

  return (
    <WidgetCard
      theme={theme}
      ref={ref}
      {...other}
      title={mockData?.title}
      widgetType='ProgressBarWidget'
    >
      {mockData ? (
        <Fragment>
          {dateRange && (
            <Typography gutterBottom variant='caption' component='h3'>
              Starting: {convertISODate(dateRange.from)}
            </Typography>
          )}

          <FluentPrimaryStatNumber
            mainStat={mockData?.value}
            mainLabel={mockData?.label}
          />
          <div>
            <LinearProgress
              variant='determinate'
              color='secondary'
              value={mockData?.progress}
            />
            {mockData?.progress}%
          </div>
          {mockData?.data && (
            <Fragment>
              <div className={classes.divider}>
                <Divider style={{ background: 'white', opacity: 0.5 }} />
              </div>
              <div className={classes.displayItems}>
                {mockData?.data.map((item, index) => {
                  return (
                    <FluentSecondaryStatNumber
                      secondaryStat={item.value}
                      secondaryLabel={item.label}
                      trend={item.trend}
                    />
                  )
                })}
              </div>
            </Fragment>
          )}
          {children}
        </Fragment>
      ) : (
        <Typography variant='subtitle2'>
          Could not retrieve widget data. Please contact support.
        </Typography>
      )}
    </WidgetCard>
  )
}

export default forwardRef(ProgressBarWidget)
