import React, { forwardRef, Fragment } from 'react'
import { Grid, Typography, makeStyles } from '@material-ui/core'
import WidgetCard from '../WidgetCard'
import { Sparklines, SparklinesLine } from 'react-sparklines'
import FluentStatsSnippet from '../FluentComponents/atoms/FluentStatsSnippet'
import { convertISODate } from '../utils/ConvertISODate'

export const layout = {
  w: { default: 2, min: 0, max: 4 },
  h: { default: 2, min: 0, max: 4 }
}

const useStyles = makeStyles((theme) => ({
  statList: {
    display: 'flex',
    flexDirection: 'row',
    justifyContent: 'space-between'
  }
}))

const SparklineWidget = (props, ref) => {
  const classes = useStyles()
  const { children, params, setParam, ...other } = props
  const { mockData, apiUrl, theme, dateRange } = params

  return (
    <WidgetCard
      className={classes.root}
      theme={theme}
      ref={ref}
      {...other}
      title={mockData?.title}
    >
      {mockData ? (
        <Fragment>
          {dateRange && (
            <Typography gutterBottom variant='caption' component='h3'>
              From: {convertISODate(dateRange.from)} to:{' '}
              {convertISODate(dateRange.to)}
            </Typography>
          )}
          <div className={classes.statList}>
            {mockData?.stats?.map((stat) => (
              <Grid item key={stat.label}>
                <FluentStatsSnippet
                  label={stat.label}
                  amount={stat.amount}
                  percent={stat.percent && stat.percent}
                  trend={stat.trend}
                />
              </Grid>
            ))}
          </div>

          <Sparklines data={mockData?.data} strokeWidth={0.5}>
            <SparklinesLine color='#067e7e' />
          </Sparklines>
          {children}
        </Fragment>
      ) : (
        <Typography variant='subtitle2'>
          Could not retrieve widget data. Please contact support.
        </Typography>
      )}
    </WidgetCard>
  )
}

export default forwardRef(SparklineWidget)
