import React, { forwardRef } from 'react'
import { Grid, Box } from '@material-ui/core'
import { MuiVegaLite } from '@material-vega/material-ui'
import WidgetCard from '../WidgetCard'
import FluentStatsSnippet from '../FluentComponents/atoms/FluentStatsSnippet'

export const layout = {
  w: { default: 2, min: 0, max: 4 },
  h: { default: 2, min: 0, max: 4 }
}

export const params = {
  mode: {
    defaultValue: 'chart'
  }
}

const SparsePlotWidget = (props, ref) => {
  const { children, params, setParam, ...other } = props
  const { mockData, apiUrl, theme } = params

  return (
    <WidgetCard ref={ref} {...other} title={mockData?.title} theme={theme}>
      <Grid container>
        {mockData?.stats.map((stat) => (
          <Grid item xs={3} key={stat.label}>
            <FluentStatsSnippet
              label={stat.label}
              amount={stat.currentValue}
              prevAmount={stat.previousValue}
            />
          </Grid>
        ))}
      </Grid>
      <Box clone flex={1} mt={1} overflow='hidden'>
        <MuiVegaLite
          spec={{
            $schema: 'https://vega.github.io/schema/vega-lite/v4.json',
            width: 'container',
            height: 'container',
            data: mockData?.data,
            mark: { type: 'point', line: true, point: true },
            encoding: {
              x: { field: 'xAxis', type: mockData?.xAxisType },
              y: { field: 'yAxis', type: mockData?.yAxisType }
            }
          }}
          variant='scatterplotChart'
          autoResize
          actions={false}
        />
      </Box>
      {children}
    </WidgetCard>
  )
}

export default forwardRef(SparsePlotWidget)
