import React, { useState } from 'react'
import { makeStyles, Fade } from '@material-ui/core'
import { FluentIconButton } from 'unity-fluent-library-demo'
import { ChevronRightIcon, ChevronLeftIcon } from '@fluentui/react-icons'

const useStyles = makeStyles((theme) => ({
  root: {
    display: 'flex',
    flexDirection: 'row',
    width: '100%',
    position: 'relative'
  },
  column: {
    display: 'flex',
    flexDirection: 'row',
    flex: 1
  },
  content: {
    flex: 1
  },
  sideBar: {
    height: '100vh',
    background: theme.palette.primary.light
  }
}))

export const SideBarTemplate = ({ children, sidebar }) => {
  const classes = useStyles()

  const [open, setOpen] = useState(true)

  const toggleSidebar = () => {
    setOpen(!open)
  }

  return (
    <div className={classes.root}>
      <div className={classes.column}>
        <div className={classes.content}>{children}</div>

        <div style={{ position: 'absolute', top: 0, right: open ? 300 : 0 }}>
          <FluentIconButton
            color='primary'
            icon={open ? ChevronRightIcon : ChevronLeftIcon}
            onClick={toggleSidebar}
          />
        </div>

        {open && (
          <Fade in={open} timeout={{ enter: 1000, exit: 1000 }}>
            <div className={classes.sideBar}>{sidebar}</div>
          </Fade>
        )}
      </div>
    </div>
  )
}
