import React from 'react'
import {
  Card,
  Chip,
  CardContent,
  makeStyles,
  useTheme,
  lighten,
  Typography,
  Divider
} from '@material-ui/core'
import { FluentIconButton } from '../../UI/inputs/buttons/FluentIconButton'
import { MapPinIcon } from '@fluentui/react-icons'

const useStyles = makeStyles((theme) => ({
  root: {
    display: 'flex',
    flexDirection: 'row'
  },
  title: {
    fontWeight: 700
  },
  titleWrapper: {
    marginBottom: theme.spacing(1)
  },
  divider: {
    // marginBottom: theme.spacing(2),
  },
  body: {
    color: lighten(theme.palette.common.black, 0.5)
  },
  actions: {
    marginTop: theme.spacing(1),
    display: 'flex',
    flexDirection: 'row'
  },
  qty: {
    marginLeft: theme.spacing(1)
  }
}))

export const TileDisplay = (props) => {
  const { title, body, selected } = props
  const classes = useStyles()
  const qty = Math.floor(Math.random() * 10) + 1
  const theme = useTheme()

  const Indicator = () => {
    return (
      <svg width='15' height='10'>
        <circle cx='70%' cy='50%' r='4' fill={theme.palette.success.main} />
      </svg>
    )
  }

  return (
    <div>
      <Card
        square
        elevation={0}
        className={classes.root}
        style={{
          background: selected && lighten(theme.palette.secondary.main, 0.9)
        }}
      >
        <CardContent>
          <div className={classes.root}>
            <div>
              <div className={classes.titleWrapper}>
                <Typography className={classes.title} variant='subtitle'>
                  {title}
                </Typography>
              </div>
              <div>
                <Typography className={classes.body} variant='caption'>
                  {body}
                </Typography>
              </div>
            </div>
            <div>
              <FluentIconButton color='primary' icon={MapPinIcon} />
            </div>
          </div>

          <div className={classes.actions}>
            <div>
              <Chip
                variant='outlined'
                size='small'
                label='Active'
                icon={<Indicator />}
              />
            </div>
            <div className={classes.qty}>
              <Chip variant='outlined' size='small' label={`Qty:${qty}`} />
            </div>
          </div>
        </CardContent>
      </Card>
      <div>
        <Divider />
      </div>
    </div>
  )
}
