import React from 'react';
import Filter from './Filter';
import ControlZoom from './ControlZoom';
import Position from './Position';
import ToggleViewType from './ToggleViewType';
import { makeStyles, Divider } from '@material-ui/core';

const useStyles = makeStyles(theme => ({
  root: {
    display: 'flex',
    flexDirection: 'row',
  },
  filter: {
    display: 'flex',
    flex: 1,
  },
  divider: {
    marginRight: theme.spacing(2),
    marginLeft: theme.spacing(2),
  },
}));

const MapControls = props => {
  const classes = useStyles();

  const {
    showLayer1,
    showLayer2,
    setShowLayer1,
    setShowLayer2,
    value,
    setZoom,
    handleSliderChange,
    handleInputChange,
    handleBlur,
    zoomIn,
    zoomOut,
    reset,
    getLocation,
    changeLat,
    changeLong,
    setPosition,
    displayType,
    handleChange,
  } = props;

  return (
    <div className={classes.root}>
      <div className={classes.filter}>
        <Filter
          showLayer1={showLayer1}
          showLayer2={showLayer2}
          setShowLayer1={setShowLayer1}
          setShowLayer2={setShowLayer2}
          getLocation={getLocation}
        />
        <ToggleViewType displayType={displayType} handleChange={handleChange} />
      </div>
      <div className={classes.divider}>
        <Divider orientation="vertical" />
      </div>

      <Position
        changeLat={changeLat}
        changeLong={changeLong}
        setPosition={setPosition}
      />

      <div className={classes.divider}>
        <Divider orientation="vertical" />
      </div>
      <div>
        <ControlZoom
          zoomIn={zoomIn}
          zoomOut={zoomOut}
          value={value}
          setValue={setZoom}
          handleSliderChange={handleSliderChange}
          handleInputChange={handleInputChange}
          handleBlur={handleBlur}
          reset={reset}
        />
      </div>
    </div>
  );
};
export default MapControls;
