import React from 'react';
import LocationPin from './LocationPin';
import ControlZoom from './ControlZoom';
import Position from './Position';
import { makeStyles, Divider } from '@material-ui/core';

const useStyles = makeStyles(theme => ({
  root: {
    display: 'flex',
    flexDirection: 'row',
  },
  filter: {
    display: 'flex',
    flex: 1,
  },
  divider: {
    marginRight: theme.spacing(2),
    marginLeft: theme.spacing(2),
  },
}));

const MapControlsStandard = props => {
  const classes = useStyles();

  const {
    value,
    setZoom,
    handleSliderChange,
    handleInputChange,
    handleBlur,
    zoomIn,
    zoomOut,
    reset,
    changeLat,
    changeLong,
    setPosition,
    getLocation,
    locations,
    tooltip,
  } = props;

  return (
    <div className={classes.root}>
      <div className={classes.filter}>
        {locations &&
          locations.map((item, index) => {
            return (
              <LocationPin
                key={index}
                location={item.location}
                getLocation={getLocation}
                tooltip={item.tooltip}
              />
            );
          })}
      </div>
      <div className={classes.divider}>
        <Divider orientation="vertical" />
      </div>

      <Position
        changeLat={changeLat}
        changeLong={changeLong}
        setPosition={setPosition}
      />

      <div className={classes.divider}>
        <Divider orientation="vertical" />
      </div>
      <div>
        <ControlZoom
          zoomIn={zoomIn}
          zoomOut={zoomOut}
          value={value}
          setValue={setZoom}
          handleSliderChange={handleSliderChange}
          handleInputChange={handleInputChange}
          handleBlur={handleBlur}
          reset={reset}
        />
      </div>
    </div>
  );
};
export default MapControlsStandard;
