import React, { useState, useEffect } from 'react'
import { makeStyles } from '@material-ui/core'
import NavigationSidebar from './ui/NavigationSidebar'
import SiteHeader from './ui/SiteHeader'
import { UtilityBar } from 'unity-fluent-library-demo'
import { useTranslation } from 'react-i18next'

const useStyles = makeStyles(
  (theme) => ({
    '@global': {
      html: {
        minHeight: '100%'
      },
      'html, body, #root': {
        display: 'flex',
        flexDirection: 'column'
      },
      'body, #root': {
        flex: 1
      }
    },
    root: {
      flex: 1,
      minHeight: '100vh',
      display: 'grid',
      gridTemplateAreas: ['sidebar header', 'sidebar content']
        .map((line) => `"${line}"`)
        .join(' '),
      gridTemplateColumns: 'auto 1fr',
      gridTemplateRows: 'auto 1fr'
    },
    header: {
      gridArea: 'header'
    },
    sidebar: {
      gridArea: 'sidebar'
    },
    content: {
      gridArea: 'content',
      display: 'flex',
      flexDirection: 'column',
      position: 'relative',
      zIndex: 1
    },
    utilityBar: {
      height: 100
    }
  }),
  { name: 'Layout' }
)

/**
 * Core site layout common to all pages
 */
export const Shell = (props) => {
  const classes = useStyles()
  const { children, userAvatar, appContent, menuList } = props
  const [expanded, setExpanded] = useState(true)

  const { i18n } = useTranslation()
  useEffect(() => {
    i18n.changeLanguage('en')
  }, [i18n])

  return (
    <div className={classes.root}>
      <SiteHeader
        className={classes.header}
        appContent={appContent}
        userAvatar={userAvatar}
      />
      <NavigationSidebar className={classes.sidebar} data={menuList} />
      <div className={classes.content}>
        <UtilityBar
          toggle={() => setExpanded((expanded) => !expanded)}
          expanded={expanded}
          className={classes.utilityBar}
          gutters={false}
        />
        {children}
      </div>
    </div>
  )
}
