import { Drawer, makeStyles } from '@material-ui/core'
import clsx from 'clsx'
import React from 'react'

const useStyles = makeStyles(
  (theme) => ({
    root: {
      width: theme?.dimensions?.drawerWidth,
      flexShrink: 0,
      whiteSpace: 'nowrap'
    },
    expanded: {
      '&, & > $paper': {
        // width: theme.dimensions.drawerWidth,
        width: theme.spacing(32),
        transition: theme.transitions.create('width', {
          easing: theme.transitions.easing.sharp,
          duration: theme.transitions.duration.enteringScreen
        })
      }
    },
    collapsed: {
      '&, & > $paper': {
        overflowX: 'hidden',
        width: theme.spacing(7) + 1,
        transition: theme.transitions.create('width', {
          easing: theme.transitions.easing.sharp,
          duration: theme.transitions.duration.leavingScreen
        })
      }
    },
    paper: {}
  }),
  { name: 'MiniCollapsibleSidebar' }
)

const MiniCollapsibleSidebar = (props) => {
  const classes = useStyles(props)
  const { expanded = true, className, children, ...other } = props

  return (
    <Drawer
      variant='permanent'
      open
      {...other}
      className={clsx(
        className,
        classes.root,
        expanded ? classes.expanded : classes.collapsed
      )}
      classes={{
        root: classes.root,
        paper: classes.paper
      }}
    >
      {children}
    </Drawer>
  )
}

export default MiniCollapsibleSidebar
