import React, { useEffect, useState } from 'react'
import {
  makeStyles,
  Toolbar,
  useMediaQuery,
  useTheme,
  lighten
} from '@material-ui/core'
import MiniCollapsibleSidebar from './MiniCollapsibleSidebar'
import { SidebarCollapseButton } from './SidebarCollapseButton'
import { AppMenu } from 'unity-fluent-library-demo'

const useStyles = makeStyles(
  (theme) => ({
    root: {
      marginTop: 400
    },
    paper: {
      backgroundColor: lighten(theme.palette.primary.main, 0.9)
    },
    list: {
      flex: 1,
      paddingTop: 0,
      overflowY: 'auto',
      WebkitOverflowScrolling: 'touch'
    },
    spacer: {
      flex: 1,
      minHeight: theme.spacing(2)
    },
    footer: {},
    toolbar: {}
  }),
  { name: 'NavigationSidebar' }
)

const NavigationSidebar = (props) => {
  const classes = useStyles()
  const { data, ...other } = props
  const theme = useTheme()
  const [expanded, setExpanded] = useState(true)
  const [hoverExpand, setHoverExpand] = useState(false)

  const wide = useMediaQuery(theme.breakpoints.up('sm'))
  useEffect(() => {
    // Set the bar to be expanded/collapsed depending on the breakpoint size
    // This works on load and also when resizing crosses the breakpoint
    setExpanded(wide)
  }, [wide])

  const handleHoverToggle = () => {
    if (!expanded) {
      setHoverExpand(true)
    }
  }
  const handleHoverLeave = () => {
    if (!expanded) {
      setHoverExpand(false)
    }
  }

  return (
    <MiniCollapsibleSidebar
      classes={{ root: classes.root, paper: classes.paper }}
      expanded={expanded || hoverExpand}
      onMouseEnter={handleHoverToggle}
      onMouseLeave={handleHoverLeave}
      PaperProps={{ elevation: 0, variant: 'outlined' }}
      {...other}
    >
      <Toolbar className={classes.toolbar} />

      <SidebarCollapseButton
        expanded={expanded}
        onClick={() => setExpanded((expanded) => !expanded)}
      />
      {data && <AppMenu menuItems={data} />}
    </MiniCollapsibleSidebar>
  )
}

export default NavigationSidebar
