import { makeStyles } from '@material-ui/core'
import clsx from 'clsx'
import React from 'react'
import { useTranslation } from 'react-i18next'
import { ChevronRightIcon } from '@fluentui/react-icons'
import { FluentIconButton } from 'unity-fluent-library-demo'

const useStyles = makeStyles(
  (theme) => ({
    root: {
      display: 'flex',
      justifyContent: 'flex-start',
      height: 48,
      width: '100%',
      paddingLeft: 0,
      paddingRight: 16
    },
    iconButton: {
      width: 48,
      height: 48,
      marginLeft: 16 - (48 - 24) / 2
    },
    expanded: {},
    icon: {
      width: 14,
      height: 14,
      margin: (24 - 16) / 2,
      transition: theme.transitions.create('transform', {
        easing: theme.transitions.easing.sharp,
        duration: theme.transitions.duration.shortest
      }),
      '$expanded &': {
        transform: 'scaleX(-1)'
      }
    },
    switch: {
      margin: (24 - 16) / 2,
      transition: theme.transitions.create('transform', {
        easing: theme.transitions.easing.sharp,
        duration: theme.transitions.duration.shortest
      }),
      '$expanded &': {
        transform: 'scaleX(-1)'
      }
    }
  }),
  { name: 'SidebarCollapseButton' }
)

/**
 * Custom styled button used for expanding/collapsing sidebars
 */
export const SidebarCollapseButton = (props) => {
  const classes = useStyles(props)
  const { expanded, className, ...other } = props
  const { t } = useTranslation()

  return (
    <div
      {...other}
      className={clsx(className, classes.root, {
        [classes.expanded]: expanded
      })}
    >
      <FluentIconButton
        color='inherit'
        className={clsx(classes.iconButton, classes.switch)}
        aria-label={
          expanded
            ? t('mainMenuAria.collapseNavigation')
            : t('mainMenuAria.expandNavigation')
        }
        icon={ChevronRightIcon}
      />
    </div>
  )
}
