import React, { Fragment } from 'react'
import {
  AppBar,
  makeStyles,
  Toolbar,
  Typography,
  IconButton
} from '@material-ui/core'
import clsx from 'clsx'
import { WaffleIcon } from '@fluentui/react-icons'
import { BreadCrumbMenu } from 'unity-fluent-library-demo'

const useStyles = makeStyles(
  (theme) => ({
    root: {
      color: theme?.palette?.appBar?.contrastText,
      zIndex: theme.zIndex.drawer + 1
      // Assume the drawer is always expanded unless the screen is too small for it and inset the left to account for it
    },
    spacer: {
      flex: 1
    },
    toolbar: {
      ...theme.mixins.toolbar
    },
    appLaunch: {
      color: theme.palette.getContrastText(theme.palette.primary.main)
    },
    avatar: {
      width: 25,
      height: 25,
      backgroundColor: theme.palette.secondary.main
    },
    search: {
      marginLeft: theme.spacing(2),
      marginTop: theme.spacing(-1.35)
    },
    children: {
      flex: 1
    }
  }),
  { name: 'SiteHeader' }
)

/**
 * A spacing component with the same height as the SiteHeader
 */
export const SiteHeaderSpacer = (props) => {
  const classes = useStyles()
  const { className } = props

  return <div className={clsx(className, classes.toolbar)} />
}

/**
 * Site header including app bar
 */
const SiteHeader = (props) => {
  const classes = useStyles(props)
  const {
    className,
    returnTo,
    appContent,
    userAvatar,
    siteName,
    ...other
  } = props

  return (
    <Fragment>
      <AppBar
        elevation={0}
        position='absolute'
        color='primary'
        {...other}
        className={className}
        classes={{ root: classes.root }}
      >
        <Toolbar>
          <IconButton
            className={classes.appLaunch}
            aria-label='App Launcher Menu'
          >
            {/* <FluentIcon component={WaffleIcon} /> */}
            <WaffleIcon />
          </IconButton>

          <Typography component='h1' variant='h3'>
            {siteName}
          </Typography>

          <div style={{ marginLeft: 70 }}>
            <BreadCrumbMenu color='primary' root='home' />
          </div>
          <div className={classes.children}>{appContent}</div>
          <div>{userAvatar}</div>
        </Toolbar>
      </AppBar>
      <SiteHeaderSpacer className={className} />
    </Fragment>
  )
}

export default SiteHeader
