import React, { Children, useCallback } from 'react';
import {
  usePopupState,
  bindTrigger,
  bindPopper,
} from 'material-ui-popup-state/hooks';
import useId from '../../UI/widgets/utils/useId';
import {
  Button,
  ButtonGroup,
  Popper,
  Grow,
  Paper,
  ClickAwayListener,
  MenuList,
  makeStyles,
} from '@material-ui/core';
import { ArrowDropDown as ArrowDropDownIcon } from '@material-ui/icons';

const useStyles = makeStyles(
  theme => ({
    arrowButtonRoot: {
      padding: 0,
    },
    menu: {
      zIndex: theme.zIndex.tooltip,
    },
    paper: {},
  }),
  { name: 'SplitButton' }
);

/**
 * https://material-ui.com/components/button-group/#split-button
 */
export const SplitButton = props => {
  const classes = useStyles(props);
  const {
    popupName,
    color,
    size,
    variant,
    label,
    'aria-label': ariaLabel,
    children,
  } = props;
  const popupId = useId(popupName);
  const popupState = usePopupState({ variant: 'popper', popupId });

  const firstItem = Children.toArray(children)[0];

  const setAnchorEl = useCallback(ref => {
    if (ref) popupState.setAnchorEl(ref);
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);

  return (
    <React.Fragment>
      <ButtonGroup
        variant={variant}
        color={color}
        size={size}
        ref={setAnchorEl}
        aria-label={ariaLabel}
      >
        <Button onClick={firstItem?.props?.onClick}>
          {label || firstItem?.props?.children}
        </Button>
        <Button
          {...bindTrigger(popupState)}
          className={classes.arrowButtonRoot}
          color={color}
          size="small"
          aria-expanded={popupState.isOpen ? true : undefined}
        // @fixme Allow labels for this button
        >
          <ArrowDropDownIcon />
        </Button>
      </ButtonGroup>
      <Popper
        {...bindPopper(popupState)}
        role={undefined}
        transition
        disablePortal
        className={classes.menu}
      >
        {({ TransitionProps, placement }) => (
          <Grow
            {...TransitionProps}
            style={{
              transformOrigin:
                placement === 'bottom' ? 'center top' : 'center bottom',
            }}
          >
            <Paper className={classes.paper}>
              <ClickAwayListener onClickAway={popupState.close}>
                <MenuList /*id={popupState.popupId}*/>{children}</MenuList>
              </ClickAwayListener>
            </Paper>
          </Grow>
        )}
      </Popper>
    </React.Fragment>
  );
};
