import * as Icons from '@fluentui/react-icons';

export const getMenuItemsRecursively = (
  menuItems,
  activeOnly,
  roleIds
) => {
  return menuItems.reduce((formattedItems, item) => {
    try {
      if (activeOnly && !item.menuItemInstance.isActive) {
        return formattedItems;
      }
      const parameters = JSON.parse(item.menuItemInstance.parameters);
      const {
        FluentIcon,
        WorkFlowIcon,
        AppIcon,
        Label,
        Slug,
        RedirectURL,
        ...otherParams
      } = parameters;
      const formattedParameters = {
        id: item.menuItemInstance.menuItemInstanceId,
        label: Label ? Label: '',
        link: Slug ? Slug : '',
        redirectInfo: RedirectURL ? RedirectURL: '',
        menuItemId: item.menuItemInstance.menuItemId,
        menuStructureId: item.menuStructureId,
        parentId: item.parentId,
        productId: item.menuItemInstance.productId,
        isActive: item.menuItemInstance.isActive,
        roleIds: item.menuItemInstance.roleIds,
        params: { ...otherParams },
      };

      let iconName = '';
      if (FluentIcon) {
        iconName = FluentIcon;
      } else if (WorkFlowIcon) {
        iconName = WorkFlowIcon;
      }
      formattedParameters.icon = iconName ? Icons[iconName] : null;
      formattedParameters.iconName = iconName ? iconName : null;

      formattedParameters['items'] = item.menuItemInstanceStructures.length
        ? getMenuItemsRecursively(
            item.menuItemInstanceStructures,
            activeOnly,
            roleIds,
          )
        : [];
      if (!roleIds) {
        formattedItems.push(formattedParameters);
      } else {
        const roleIdMatch = roleIds?.filter(id => formattedParameters.roleIds?.includes(id));
        if (roleIdMatch?.length || !formattedParameters.roleIds?.length) {
          formattedItems.push(formattedParameters);
        }
      }
    } catch {
      // catching parse error
    }
    return formattedItems;
  }, []);
};
